@@ -1,3 +1,9 @@
+/*
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ */
+
 #ifndef OBEXAGENTMANAGER_H
 #define OBEXAGENTMANAGER_H
 
@@ -13,7 +19,7 @@ class ObexAgentManager : public QDBusAbstractAdaptor, public Object
     Q_CLASSINFO("D-Bus Interface", "org.bluez.obex.AgentManager1")
 
 public:
-    explicit ObexAgentManager(QObject *parent = Q_NULLPTR);
+    explicit ObexAgentManager(QObject *parent = nullptr);
 
     void runAction(const QString &actionName, const QVariantMap &properties);
 
