@@ -1,23 +1,9 @@
 /*
  * BluezQt - Asynchronous Bluez wrapper library
  *
- * Copyright (C) 2014 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "device.h"
@@ -27,7 +13,6 @@
 
 namespace BluezQt
 {
-
 Device::Device(const QString &path, const QVariantMap &properties, AdapterPtr adapter)
     : QObject()
     , d(new DevicePrivate(path, properties, adapter))
@@ -61,8 +46,7 @@ QString Device::name() const
 
 PendingCall *Device::setName(const QString &name)
 {
-    return new PendingCall(d->setDBusProperty(QStringLiteral("Alias"), name),
-                           PendingCall::ReturnVoid, this);
+    return new PendingCall(d->setDBusProperty(QStringLiteral("Alias"), name), PendingCall::ReturnVoid, this);
 }
 
 QString Device::friendlyName() const
@@ -88,6 +72,10 @@ quint32 Device::deviceClass() const
 
 Device::Type Device::type() const
 {
+    if (deviceClass() == 0) {
+        return appearanceToType(appearance());
+    }
+
     return classToType(d->m_deviceClass);
 }
 
@@ -120,8 +108,7 @@ bool Device::isTrusted() const
 
 PendingCall *Device::setTrusted(bool trusted)
 {
-    return new PendingCall(d->setDBusProperty(QStringLiteral("Trusted"), trusted),
-                           PendingCall::ReturnVoid, this);
+    return new PendingCall(d->setDBusProperty(QStringLiteral("Trusted"), trusted), PendingCall::ReturnVoid, this);
 }
 
 bool Device::isBlocked() const
@@ -131,8 +118,7 @@ bool Device::isBlocked() const
 
 PendingCall *Device::setBlocked(bool blocked)
 {
-    return new PendingCall(d->setDBusProperty(QStringLiteral("Blocked"), blocked),
-                           PendingCall::ReturnVoid, this);
+    return new PendingCall(d->setDBusProperty(QStringLiteral("Blocked"), blocked), PendingCall::ReturnVoid, this);
 }
 
 bool Device::hasLegacyPairing() const
@@ -145,6 +131,16 @@ qint16 Device::rssi() const
     return d->m_rssi;
 }
 
+ManData Device::manufacturerData() const
+{
+    return d->m_manufacturerData;
+}
+
+bool Device::isServicesResolved() const
+{
+    return d->m_servicesResolved;
+}
+
 bool Device::isConnected() const
 {
     return d->m_connected;
@@ -160,6 +156,16 @@ QString Device::modalias() const
     return d->m_modalias;
 }
 
+QHash<QString, QByteArray> Device::serviceData() const
+{
+    return d->m_serviceData;
+}
+
+BatteryPtr Device::battery() const
+{
+    return d->m_battery;
+}
+
 InputPtr Device::input() const
 {
     return d->m_input;
@@ -170,11 +176,21 @@ MediaPlayerPtr Device::mediaPlayer() const
     return d->m_mediaPlayer;
 }
 
+MediaTransportPtr Device::mediaTransport() const
+{
+    return d->m_mediaTransport;
+}
+
 AdapterPtr Device::adapter() const
 {
     return d->m_adapter;
 }
 
+QList<GattServiceRemotePtr> Device::gattServices() const
+{
+    return d->m_services;
+}
+
 QString Device::typeToString(Device::Type type)
 {
     switch (type) {
