@@ -11,21 +11,20 @@
 
 #include <QSortFilterProxyModel>
 
+#include "declarativemanager.h"
 #include "devicesmodel.h"
 
-class DeclarativeManager;
-
 class DeclarativeDevicesModel : public QSortFilterProxyModel
 {
     Q_OBJECT
-    Q_PROPERTY(DeclarativeManager* manager READ manager WRITE setManager)
+    Q_PROPERTY(DeclarativeManager *manager READ manager WRITE setManager)
 
 public:
     enum DeclarativeDeviceRoles {
         DeviceRole = BluezQt::DevicesModel::LastRole + 1,
         AdapterRole = BluezQt::DevicesModel::LastRole + 2,
         MediaPlayerRole = BluezQt::DevicesModel::LastRole + 3,
-        BatteryRole = BluezQt::DevicesModel::LastRole + 4
+        BatteryRole = BluezQt::DevicesModel::LastRole + 4,
     };
 
     explicit DeclarativeDevicesModel(QObject *parent = nullptr);
@@ -42,4 +41,3 @@ private:
 };
 
 #endif // DECLARATIVEMANAGER_H
-
