@@ -7,41 +7,55 @@
  */
 
 #include "declarativemanager.h"
+#include "adapter.h"
 #include "declarativeadapter.h"
 #include "declarativedevice.h"
-#include "initmanagerjob.h"
-#include "adapter.h"
 #include "device.h"
-
-
+#include "initmanagerjob.h"
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+static qsizetype adaptersCountFunction(QQmlListProperty<DeclarativeAdapter> *property)
+#else
 static int adaptersCountFunction(QQmlListProperty<DeclarativeAdapter> *property)
+#endif
 {
-    Q_ASSERT(qobject_cast<DeclarativeManager*>(property->object));
-    DeclarativeManager *manager = static_cast<DeclarativeManager*>(property->object);
+    Q_ASSERT(qobject_cast<DeclarativeManager *>(property->object));
+    DeclarativeManager *manager = static_cast<DeclarativeManager *>(property->object);
 
     return manager->m_adapters.count();
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+static DeclarativeAdapter *adaptersAtFunction(QQmlListProperty<DeclarativeAdapter> *property, qsizetype index)
+#else
 static DeclarativeAdapter *adaptersAtFunction(QQmlListProperty<DeclarativeAdapter> *property, int index)
+#endif
 {
-    Q_ASSERT(qobject_cast<DeclarativeManager*>(property->object));
-    DeclarativeManager *manager = static_cast<DeclarativeManager*>(property->object);
+    Q_ASSERT(qobject_cast<DeclarativeManager *>(property->object));
+    DeclarativeManager *manager = static_cast<DeclarativeManager *>(property->object);
 
     return manager->m_adapters.values().at(index);
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+static qsizetype devicesCountFunction(QQmlListProperty<DeclarativeDevice> *property)
+#else
 static int devicesCountFunction(QQmlListProperty<DeclarativeDevice> *property)
+#endif
 {
-    Q_ASSERT(qobject_cast<DeclarativeManager*>(property->object));
-    DeclarativeManager *manager = static_cast<DeclarativeManager*>(property->object);
+    Q_ASSERT(qobject_cast<DeclarativeManager *>(property->object));
+    DeclarativeManager *manager = static_cast<DeclarativeManager *>(property->object);
 
     return manager->m_devices.count();
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+static DeclarativeDevice *devicesAtFunction(QQmlListProperty<DeclarativeDevice> *property, qsizetype index)
+#else
 static DeclarativeDevice *devicesAtFunction(QQmlListProperty<DeclarativeDevice> *property, int index)
+#endif
 {
-    Q_ASSERT(qobject_cast<DeclarativeManager*>(property->object));
-    DeclarativeManager *manager = static_cast<DeclarativeManager*>(property->object);
+    Q_ASSERT(qobject_cast<DeclarativeManager *>(property->object));
+    DeclarativeManager *manager = static_cast<DeclarativeManager *>(property->object);
 
     return manager->m_devices.values().at(index);
 }
