@@ -1,41 +1,25 @@
 /*
  * BluezQt - Asynchronous Bluez wrapper library
  *
- * Copyright (C) 2014 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "manager.h"
-#include "manager_p.h"
-#include "adapter.h"
 #include "agent.h"
 #include "agentadaptor.h"
+#include "debug.h"
+#include "initmanagerjob.h"
+#include "manager_p.h"
+#include "pendingcall.h"
 #include "profile.h"
 #include "profile_p.h"
 #include "profileadaptor.h"
-#include "pendingcall.h"
-#include "initmanagerjob.h"
 #include "utils.h"
-#include "debug.h"
 
 namespace BluezQt
 {
-
 Manager::Manager(QObject *parent)
     : QObject(parent)
     , d(new ManagerPrivate(this))
@@ -111,7 +95,7 @@ PendingCall *Manager::startService()
 
 AdapterPtr Manager::adapterForAddress(const QString &address) const
 {
-    for (AdapterPtr adapter : qAsConst(d->m_adapters)) {
+    for (AdapterPtr adapter : std::as_const(d->m_adapters)) {
         if (adapter->address() == address) {
             return adapter;
         }
@@ -128,7 +112,7 @@ DevicePtr Manager::deviceForAddress(const QString &address) const
 {
     DevicePtr device;
 
-    for (AdapterPtr adapter : qAsConst(d->m_adapters)) {
+    for (AdapterPtr adapter : std::as_const(d->m_adapters)) {
         DevicePtr d = adapter->deviceForAddress(address);
         if (!d) {
             continue;
@@ -184,8 +168,7 @@ PendingCall *Manager::registerAgent(Agent *agent)
         qCDebug(BLUEZQT) << "Cannot register object" << agent->objectPath().path();
     }
 
-    return new PendingCall(d->m_bluezAgentManager->RegisterAgent(agent->objectPath(), capability),
-                           PendingCall::ReturnVoid, this);
+    return new PendingCall(d->m_bluezAgentManager->RegisterAgent(agent->objectPath(), capability), PendingCall::ReturnVoid, this);
 }
 
 PendingCall *Manager::unregisterAgent(Agent *agent)
@@ -198,8 +181,7 @@ PendingCall *Manager::unregisterAgent(Agent *agent)
 
     DBusConnection::orgBluez().unregisterObject(agent->objectPath().path());
 
-    return new PendingCall(d->m_bluezAgentManager->UnregisterAgent(agent->objectPath()),
-                           PendingCall::ReturnVoid, this);
+    return new PendingCall(d->m_bluezAgentManager->UnregisterAgent(agent->objectPath()), PendingCall::ReturnVoid, this);
 }
 
 PendingCall *Manager::requestDefaultAgent(Agent *agent)
@@ -210,8 +192,7 @@ PendingCall *Manager::requestDefaultAgent(Agent *agent)
         return new PendingCall(PendingCall::InternalError, QStringLiteral("Manager not operational!"));
     }
 
-    return new PendingCall(d->m_bluezAgentManager->RequestDefaultAgent(agent->objectPath()),
-                           PendingCall::ReturnVoid, this);
+    return new PendingCall(d->m_bluezAgentManager->RequestDefaultAgent(agent->objectPath()), PendingCall::ReturnVoid, this);
 }
 
 PendingCall *Manager::registerProfile(Profile *profile)
@@ -229,7 +210,8 @@ PendingCall *Manager::registerProfile(Profile *profile)
     }
 
     return new PendingCall(d->m_bluezProfileManager->RegisterProfile(profile->objectPath(), profile->uuid(), profile->d->options),
-                           PendingCall::ReturnVoid, this);
+                           PendingCall::ReturnVoid,
+                           this);
 }
 
 PendingCall *Manager::unregisterProfile(Profile *profile)
@@ -242,13 +224,19 @@ PendingCall *Manager::unregisterProfile(Profile *profile)
 
     DBusConnection::orgBluez().unregisterObject(profile->objectPath().path());
 
-    return new PendingCall(d->m_bluezProfileManager->UnregisterProfile(profile->objectPath()),
-                           PendingCall::ReturnVoid, this);
+    return new PendingCall(d->m_bluezProfileManager->UnregisterProfile(profile->objectPath()), PendingCall::ReturnVoid, this);
 }
 
+#if BLUEZQT_BUILD_DEPRECATED_SINCE(5, 57)
 MediaPtr Manager::media() const
 {
     return usableAdapter() ? usableAdapter()->media() : nullptr;
 }
+#endif
+
+Rfkill *Manager::rfkill() const
+{
+    return d->m_rfkill;
+}
 
 } // namespace BluezQt
